
################################################################
# This is a generated script based on design: ps7
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

namespace eval _tcl {
proc get_script_folder {} {
   set script_path [file normalize [info script]]
   set script_folder [file dirname $script_path]
   return $script_folder
}
}
variable script_folder
set script_folder [_tcl::get_script_folder]

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2017.2
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   catch {common::send_msg_id "BD_TCL-109" "ERROR" "This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."}

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source ps7_script.tcl

# If there is no project opened, this script will create a
# project, but make sure you do not have an existing project
# <./myproj/project_1.xpr> in the current working folder.

set list_projs [get_projects -quiet]
if { $list_projs eq "" } {
   create_project project_1 myproj -part xc7z045ffg900-2
   set_property BOARD_PART xilinx.com:zc706:part0:1.2 [current_project]
}


# CHANGE DESIGN NAME HERE
set design_name ps7

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      common::send_msg_id "BD_TCL-001" "INFO" "Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   common::send_msg_id "BD_TCL-002" "INFO" "Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   common::send_msg_id "BD_TCL-003" "INFO" "Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   common::send_msg_id "BD_TCL-004" "INFO" "Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

common::send_msg_id "BD_TCL-005" "INFO" "Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   catch {common::send_msg_id "BD_TCL-114" "ERROR" $errMsg}
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################



# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  variable script_folder

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]
  set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]
  set UART_0 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:uart_rtl:1.0 UART_0 ]
  set clking_axi [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 clking_axi ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.DATA_WIDTH {32} \
CONFIG.FREQ_HZ {100000000.0} \
CONFIG.PROTOCOL {AXI4LITE} \
 ] $clking_axi
  set intr_axi [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 intr_axi ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.DATA_WIDTH {32} \
CONFIG.FREQ_HZ {100000000} \
CONFIG.PROTOCOL {AXI4LITE} \
 ] $intr_axi
  set rab_acp [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 rab_acp ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.ARUSER_WIDTH {6} \
CONFIG.AWUSER_WIDTH {6} \
CONFIG.BUSER_WIDTH {6} \
CONFIG.DATA_WIDTH {64} \
CONFIG.FREQ_HZ {100000000} \
CONFIG.HAS_BRESP {1} \
CONFIG.HAS_BURST {1} \
CONFIG.HAS_CACHE {1} \
CONFIG.HAS_LOCK {1} \
CONFIG.HAS_PROT {1} \
CONFIG.HAS_QOS {1} \
CONFIG.HAS_REGION {1} \
CONFIG.HAS_RRESP {1} \
CONFIG.HAS_WSTRB {1} \
CONFIG.ID_WIDTH {3} \
CONFIG.MAX_BURST_LENGTH {256} \
CONFIG.NUM_READ_OUTSTANDING {1} \
CONFIG.NUM_READ_THREADS {1} \
CONFIG.NUM_WRITE_OUTSTANDING {1} \
CONFIG.NUM_WRITE_THREADS {1} \
CONFIG.PHASE {0.000} \
CONFIG.PROTOCOL {AXI4} \
CONFIG.READ_WRITE_MODE {READ_WRITE} \
CONFIG.RUSER_BITS_PER_BYTE {0} \
CONFIG.RUSER_WIDTH {6} \
CONFIG.SUPPORTS_NARROW_BURST {1} \
CONFIG.WUSER_BITS_PER_BYTE {0} \
CONFIG.WUSER_WIDTH {6} \
 ] $rab_acp
  set rab_ar_bram [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 rab_ar_bram ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $rab_ar_bram
  set rab_aw_bram [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 rab_aw_bram ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $rab_aw_bram
  set rab_lite [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 rab_lite ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.DATA_WIDTH {32} \
CONFIG.FREQ_HZ {100000000} \
CONFIG.PROTOCOL {AXI4LITE} \
 ] $rab_lite
  set rab_master [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 rab_master ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.ARUSER_WIDTH {6} \
CONFIG.AWUSER_WIDTH {6} \
CONFIG.BUSER_WIDTH {6} \
CONFIG.DATA_WIDTH {64} \
CONFIG.FREQ_HZ {100000000} \
CONFIG.HAS_BRESP {1} \
CONFIG.HAS_BURST {1} \
CONFIG.HAS_CACHE {1} \
CONFIG.HAS_LOCK {1} \
CONFIG.HAS_PROT {1} \
CONFIG.HAS_QOS {1} \
CONFIG.HAS_REGION {1} \
CONFIG.HAS_RRESP {1} \
CONFIG.HAS_WSTRB {1} \
CONFIG.ID_WIDTH {6} \
CONFIG.MAX_BURST_LENGTH {256} \
CONFIG.NUM_READ_OUTSTANDING {8} \
CONFIG.NUM_READ_THREADS {1} \
CONFIG.NUM_WRITE_OUTSTANDING {8} \
CONFIG.NUM_WRITE_THREADS {1} \
CONFIG.PHASE {0.000} \
CONFIG.PROTOCOL {AXI4} \
CONFIG.READ_WRITE_MODE {READ_WRITE} \
CONFIG.RUSER_BITS_PER_BYTE {0} \
CONFIG.RUSER_WIDTH {6} \
CONFIG.SUPPORTS_NARROW_BURST {1} \
CONFIG.WUSER_BITS_PER_BYTE {0} \
CONFIG.WUSER_WIDTH {6} \
 ] $rab_master
  set rab_slave [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 rab_slave ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.DATA_WIDTH {64} \
CONFIG.PROTOCOL {AXI4} \
 ] $rab_slave

  # Create ports
  set ClkIcHost_CO [ create_bd_port -dir O -type clk ClkIcHost_CO ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_RESET {RstIcHost_RBI} \
 ] $ClkIcHost_CO
  set ClkIcPulpGated_CI [ create_bd_port -dir I -type clk ClkIcPulpGated_CI ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_BUSIF {rab_master:rab_acp} \
CONFIG.ASSOCIATED_RESET {RstIcPulpGated_RBI} \
 ] $ClkIcPulpGated_CI
  set ClkIcPulp_CI [ create_bd_port -dir I -type clk ClkIcPulp_CI ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_BUSIF {rab_lite:rab_slave:intr_axi} \
CONFIG.ASSOCIATED_RESET {RstIcPulp_RBI} \
 ] $ClkIcPulp_CI
  set RstIcHost_RBI [ create_bd_port -dir I -type rst RstIcHost_RBI ]
  set RstIcHost_RBO [ create_bd_port -dir O -type rst RstIcHost_RBO ]
  set RstIcPulpGated_RBI [ create_bd_port -dir I -type rst RstIcPulpGated_RBI ]
  set RstIcPulp_RBI [ create_bd_port -dir I -type rst RstIcPulp_RBI ]
  set RstPulp_RBO [ create_bd_port -dir O -type rst RstPulp_RBO ]
  set host2pulp_gpio [ create_bd_port -dir O -from 31 -to 0 host2pulp_gpio ]
  set pulp2host_gpio [ create_bd_port -dir I -from 31 -to 0 pulp2host_gpio ]
  set pulp2host_intr [ create_bd_port -dir I pulp2host_intr ]

  # Create instance: axi_clock_converter_0, and set properties
  set axi_clock_converter_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_0 ]
  set_property -dict [ list \
CONFIG.ACLK_ASYNC {1} \
 ] $axi_clock_converter_0

  # Create instance: axi_clock_converter_1, and set properties
  set axi_clock_converter_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_1 ]
  set_property -dict [ list \
CONFIG.ACLK_ASYNC {1} \
 ] $axi_clock_converter_1

  # Create instance: axi_clock_converter_acp, and set properties
  set axi_clock_converter_acp [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_acp ]
  set_property -dict [ list \
CONFIG.ACLK_ASYNC {1} \
 ] $axi_clock_converter_acp

  # Create instance: axi_crossbar_0, and set properties
  set axi_crossbar_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_crossbar:2.1 axi_crossbar_0 ]
  set_property -dict [ list \
CONFIG.DATA_WIDTH {32} \
CONFIG.NUM_MI {5} \
CONFIG.S01_BASE_ID {0x00001000} \
CONFIG.S02_BASE_ID {0x00002000} \
CONFIG.S03_BASE_ID {0x00003000} \
CONFIG.S04_BASE_ID {0x00004000} \
CONFIG.S05_BASE_ID {0x00005000} \
CONFIG.S06_BASE_ID {0x00006000} \
CONFIG.S07_BASE_ID {0x00007000} \
CONFIG.S08_BASE_ID {0x00008000} \
CONFIG.S09_BASE_ID {0x00009000} \
CONFIG.S10_BASE_ID {0x0000a000} \
CONFIG.S11_BASE_ID {0x0000b000} \
CONFIG.S12_BASE_ID {0x0000c000} \
CONFIG.S13_BASE_ID {0x0000d000} \
CONFIG.S14_BASE_ID {0x0000e000} \
CONFIG.S15_BASE_ID {0x0000f000} \
CONFIG.STRATEGY {2} \
 ] $axi_crossbar_0

  # Create instance: axi_crossbar_1, and set properties
  set axi_crossbar_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_crossbar:2.1 axi_crossbar_1 ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.CONNECTIVITY_MODE {SASD} \
CONFIG.NUM_MI {3} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.R_REGISTER {1} \
 ] $axi_crossbar_1

  # Create instance: axi_dwidth_converter_0, and set properties
  set axi_dwidth_converter_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_0 ]
  set_property -dict [ list \
CONFIG.ACLK_ASYNC {1} \
CONFIG.FIFO_MODE {2} \
CONFIG.MI_DATA_WIDTH {64} \
CONFIG.SI_DATA_WIDTH {32} \
 ] $axi_dwidth_converter_0

  # Create instance: axi_protocol_conv_ar_log, and set properties
  set axi_protocol_conv_ar_log [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_conv_ar_log ]
  set_property -dict [ list \
CONFIG.MI_PROTOCOL {AXI4LITE} \
CONFIG.SI_PROTOCOL {AXI4} \
CONFIG.TRANSLATION_MODE {2} \
 ] $axi_protocol_conv_ar_log

  # Create instance: axi_protocol_conv_aw_log, and set properties
  set axi_protocol_conv_aw_log [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_conv_aw_log ]
  set_property -dict [ list \
CONFIG.MI_PROTOCOL {AXI4LITE} \
CONFIG.SI_PROTOCOL {AXI4} \
CONFIG.TRANSLATION_MODE {2} \
 ] $axi_protocol_conv_aw_log

  # Create instance: axi_protocol_converter_0, and set properties
  set axi_protocol_converter_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_converter_0 ]
  set_property -dict [ list \
CONFIG.MI_PROTOCOL {AXI4} \
CONFIG.SI_PROTOCOL {AXI3} \
 ] $axi_protocol_converter_0

  # Create instance: axi_protocol_converter_1, and set properties
  set axi_protocol_converter_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_converter_1 ]
  set_property -dict [ list \
CONFIG.MI_PROTOCOL {AXI4LITE} \
CONFIG.SI_PROTOCOL {AXI4} \
CONFIG.TRANSLATION_MODE {2} \
 ] $axi_protocol_converter_1

  # Create instance: axi_protocol_converter_2, and set properties
  set axi_protocol_converter_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_converter_2 ]
  set_property -dict [ list \
CONFIG.MI_PROTOCOL {AXI4LITE} \
CONFIG.SI_PROTOCOL {AXI4} \
CONFIG.TRANSLATION_MODE {2} \
 ] $axi_protocol_converter_2

  # Create instance: axi_protocol_converter_3, and set properties
  set axi_protocol_converter_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_converter_3 ]

  # Create instance: axi_protocol_converter_acp, and set properties
  set axi_protocol_converter_acp [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter:2.1 axi_protocol_converter_acp ]

  # Create instance: axi_pulp_control, and set properties
  set axi_pulp_control [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_gpio:2.0 axi_pulp_control ]
  set_property -dict [ list \
CONFIG.C_ALL_INPUTS {1} \
CONFIG.C_ALL_OUTPUTS_2 {1} \
CONFIG.C_DOUT_DEFAULT_2 {0xC0000000} \
CONFIG.C_IS_DUAL {1} \
 ] $axi_pulp_control

  # Create instance: processing_system7_0, and set properties
  set processing_system7_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7:5.5 processing_system7_0 ]
  set_property -dict [ list \
CONFIG.PCW_APU_PERIPHERAL_FREQMHZ {800} \
CONFIG.PCW_ENET0_PERIPHERAL_FREQMHZ {1000 Mbps} \
CONFIG.PCW_EN_RST1_PORT {1} \
CONFIG.PCW_FPGA0_PERIPHERAL_FREQMHZ {100.0} \
CONFIG.PCW_IRQ_F2P_INTR {1} \
CONFIG.PCW_S_AXI_HP0_DATA_WIDTH {64} \
CONFIG.PCW_UART0_GRP_FULL_ENABLE {1} \
CONFIG.PCW_UART0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_USE_DEFAULT_ACP_USER_VAL {1} \
CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
CONFIG.PCW_USE_M_AXI_GP0 {1} \
CONFIG.PCW_USE_M_AXI_GP1 {0} \
CONFIG.PCW_USE_S_AXI_ACP {1} \
CONFIG.PCW_USE_S_AXI_HP0 {1} \
CONFIG.preset {ZC706} \
 ] $processing_system7_0

  # Create instance: rab_ar_bram_ctrl_host, and set properties
  set rab_ar_bram_ctrl_host [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 rab_ar_bram_ctrl_host ]
  set_property -dict [ list \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $rab_ar_bram_ctrl_host

  # Create instance: rab_aw_bram_ctrl_host, and set properties
  set rab_aw_bram_ctrl_host [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 rab_aw_bram_ctrl_host ]
  set_property -dict [ list \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $rab_aw_bram_ctrl_host

  # Create interface connections
  connect_bd_intf_net -intf_net axi_clock_converter_0_M_AXI [get_bd_intf_pins axi_clock_converter_0/M_AXI] [get_bd_intf_pins axi_crossbar_1/S00_AXI]
  connect_bd_intf_net -intf_net axi_clock_converter_1_M_AXI [get_bd_intf_pins axi_clock_converter_1/M_AXI] [get_bd_intf_pins axi_protocol_converter_3/S_AXI]
  connect_bd_intf_net -intf_net axi_clock_converter_acp_M_AXI [get_bd_intf_pins axi_clock_converter_acp/M_AXI] [get_bd_intf_pins axi_protocol_converter_acp/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_0_M00_AXI [get_bd_intf_pins axi_crossbar_0/M00_AXI] [get_bd_intf_pins axi_protocol_converter_1/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_0_M02_AXI [get_bd_intf_pins axi_crossbar_0/M01_AXI] [get_bd_intf_pins axi_dwidth_converter_0/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_0_M03_AXI [get_bd_intf_pins axi_crossbar_0/M02_AXI] [get_bd_intf_pins axi_protocol_converter_2/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_0_M03_AXI1 [get_bd_intf_pins axi_crossbar_0/M03_AXI] [get_bd_intf_pins axi_protocol_conv_ar_log/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_0_M04_AXI [get_bd_intf_pins axi_crossbar_0/M04_AXI] [get_bd_intf_pins axi_protocol_conv_aw_log/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_1_M00_AXI [get_bd_intf_pins axi_crossbar_1/M00_AXI] [get_bd_intf_pins axi_pulp_control/S_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_1_M01_AXI [get_bd_intf_ports rab_lite] [get_bd_intf_pins axi_crossbar_1/M01_AXI]
  connect_bd_intf_net -intf_net axi_crossbar_1_M02_AXI [get_bd_intf_ports intr_axi] [get_bd_intf_pins axi_crossbar_1/M02_AXI]
  connect_bd_intf_net -intf_net axi_dwidth_converter_0_M_AXI [get_bd_intf_ports rab_slave] [get_bd_intf_pins axi_dwidth_converter_0/M_AXI]
  connect_bd_intf_net -intf_net axi_protocol_conv_ar_log_M_AXI [get_bd_intf_pins axi_protocol_conv_ar_log/M_AXI] [get_bd_intf_pins rab_ar_bram_ctrl_host/S_AXI]
  connect_bd_intf_net -intf_net axi_protocol_conv_aw_log_M_AXI [get_bd_intf_pins axi_protocol_conv_aw_log/M_AXI] [get_bd_intf_pins rab_aw_bram_ctrl_host/S_AXI]
  connect_bd_intf_net -intf_net axi_protocol_converter_0_M_AXI [get_bd_intf_pins axi_crossbar_0/S00_AXI] [get_bd_intf_pins axi_protocol_converter_0/M_AXI]
  connect_bd_intf_net -intf_net axi_protocol_converter_1_M_AXI [get_bd_intf_ports clking_axi] [get_bd_intf_pins axi_protocol_converter_1/M_AXI]
  connect_bd_intf_net -intf_net axi_protocol_converter_2_M_AXI [get_bd_intf_pins axi_clock_converter_0/S_AXI] [get_bd_intf_pins axi_protocol_converter_2/M_AXI]
  connect_bd_intf_net -intf_net axi_protocol_converter_3_M_AXI [get_bd_intf_pins axi_protocol_converter_3/M_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP0]
  connect_bd_intf_net -intf_net axi_protocol_converter_acp_M_AXI [get_bd_intf_pins axi_protocol_converter_acp/M_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_ACP]
  connect_bd_intf_net -intf_net processing_system7_0_DDR [get_bd_intf_ports DDR] [get_bd_intf_pins processing_system7_0/DDR]
  connect_bd_intf_net -intf_net processing_system7_0_FIXED_IO [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins processing_system7_0/FIXED_IO]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP0 [get_bd_intf_pins axi_protocol_converter_0/S_AXI] [get_bd_intf_pins processing_system7_0/M_AXI_GP0]
  connect_bd_intf_net -intf_net processing_system7_0_UART_0 [get_bd_intf_ports UART_0] [get_bd_intf_pins processing_system7_0/UART_0]
  connect_bd_intf_net -intf_net rab_ar_bram_ctrl_host_BRAM_PORTA [get_bd_intf_ports rab_ar_bram] [get_bd_intf_pins rab_ar_bram_ctrl_host/BRAM_PORTA]
  connect_bd_intf_net -intf_net rab_aw_bram_ctrl_host_BRAM_PORTA [get_bd_intf_ports rab_aw_bram] [get_bd_intf_pins rab_aw_bram_ctrl_host/BRAM_PORTA]
  connect_bd_intf_net -intf_net rab_master_1 [get_bd_intf_ports rab_master] [get_bd_intf_pins axi_clock_converter_1/S_AXI]
  connect_bd_intf_net -intf_net rab_master_acp [get_bd_intf_ports rab_acp] [get_bd_intf_pins axi_clock_converter_acp/S_AXI]

  # Create port connections
  connect_bd_net -net ClkIcPulpGated_CI_1 [get_bd_ports ClkIcPulpGated_CI] [get_bd_pins axi_clock_converter_1/s_axi_aclk] [get_bd_pins axi_clock_converter_acp/s_axi_aclk]
  connect_bd_net -net ClkIcPulp_CI_1 [get_bd_ports ClkIcPulp_CI] [get_bd_pins axi_clock_converter_0/m_axi_aclk] [get_bd_pins axi_crossbar_1/aclk] [get_bd_pins axi_dwidth_converter_0/m_axi_aclk] [get_bd_pins axi_pulp_control/s_axi_aclk]
  connect_bd_net -net RstIcHost_RBI_1 [get_bd_ports RstIcHost_RBI] [get_bd_pins axi_clock_converter_0/s_axi_aresetn] [get_bd_pins axi_clock_converter_1/m_axi_aresetn] [get_bd_pins axi_clock_converter_acp/m_axi_aresetn] [get_bd_pins axi_crossbar_0/aresetn] [get_bd_pins axi_dwidth_converter_0/s_axi_aresetn] [get_bd_pins axi_protocol_conv_ar_log/aresetn] [get_bd_pins axi_protocol_conv_aw_log/aresetn] [get_bd_pins axi_protocol_converter_0/aresetn] [get_bd_pins axi_protocol_converter_1/aresetn] [get_bd_pins axi_protocol_converter_2/aresetn] [get_bd_pins axi_protocol_converter_3/aresetn] [get_bd_pins axi_protocol_converter_acp/aresetn] [get_bd_pins rab_ar_bram_ctrl_host/s_axi_aresetn] [get_bd_pins rab_aw_bram_ctrl_host/s_axi_aresetn]
  connect_bd_net -net RstIcPulpGated_RBI_1 [get_bd_ports RstIcPulpGated_RBI] [get_bd_pins axi_clock_converter_1/s_axi_aresetn] [get_bd_pins axi_clock_converter_acp/s_axi_aresetn]
  connect_bd_net -net RstIcPulp_RBI_1 [get_bd_ports RstIcPulp_RBI] [get_bd_pins axi_clock_converter_0/m_axi_aresetn] [get_bd_pins axi_crossbar_1/aresetn] [get_bd_pins axi_dwidth_converter_0/m_axi_aresetn] [get_bd_pins axi_pulp_control/s_axi_aresetn]
  connect_bd_net -net axi_pulp_control_gpio2_io_o [get_bd_ports host2pulp_gpio] [get_bd_pins axi_pulp_control/gpio2_io_o]
  connect_bd_net -net axi_pulp_control_gpio_io_i [get_bd_ports pulp2host_gpio] [get_bd_pins axi_pulp_control/gpio_io_i]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_ports ClkIcHost_CO] [get_bd_pins axi_clock_converter_0/s_axi_aclk] [get_bd_pins axi_clock_converter_1/m_axi_aclk] [get_bd_pins axi_clock_converter_acp/m_axi_aclk] [get_bd_pins axi_crossbar_0/aclk] [get_bd_pins axi_dwidth_converter_0/s_axi_aclk] [get_bd_pins axi_protocol_conv_ar_log/aclk] [get_bd_pins axi_protocol_conv_aw_log/aclk] [get_bd_pins axi_protocol_converter_0/aclk] [get_bd_pins axi_protocol_converter_1/aclk] [get_bd_pins axi_protocol_converter_2/aclk] [get_bd_pins axi_protocol_converter_3/aclk] [get_bd_pins axi_protocol_converter_acp/aclk] [get_bd_pins processing_system7_0/FCLK_CLK0] [get_bd_pins processing_system7_0/M_AXI_GP0_ACLK] [get_bd_pins processing_system7_0/S_AXI_ACP_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP0_ACLK] [get_bd_pins rab_ar_bram_ctrl_host/s_axi_aclk] [get_bd_pins rab_aw_bram_ctrl_host/s_axi_aclk]
  connect_bd_net -net processing_system7_0_FCLK_RESET0_N [get_bd_ports RstIcHost_RBO] [get_bd_pins processing_system7_0/FCLK_RESET0_N]
  connect_bd_net -net processing_system7_0_FCLK_RESET1_N [get_bd_ports RstPulp_RBO] [get_bd_pins processing_system7_0/FCLK_RESET1_N]
  connect_bd_net -net pulp2host_intr_1 [get_bd_ports pulp2host_intr] [get_bd_pins processing_system7_0/IRQ_F2P]

  # Create address segments
  create_bd_addr_seg -range 0x00010000 -offset 0x51000000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs axi_pulp_control/S_AXI/Reg] SEG_axi_pulp_control_Reg
  create_bd_addr_seg -range 0x00010000 -offset 0x51010000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs clking_axi/Reg] SEG_clking_axi_Reg
  create_bd_addr_seg -range 0x00010000 -offset 0x51050000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs intr_axi/Reg] SEG_intr_axi_Reg
  create_bd_addr_seg -range 0x00100000 -offset 0x51100000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs rab_ar_bram_ctrl_host/S_AXI/Mem0] SEG_rab_ar_bram_ctrl_host_Mem0
  create_bd_addr_seg -range 0x00100000 -offset 0x51200000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs rab_aw_bram_ctrl_host/S_AXI/Mem0] SEG_rab_aw_bram_ctrl_host_Mem0
  create_bd_addr_seg -range 0x00010000 -offset 0x51030000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs rab_lite/Reg] SEG_rab_lite_Reg
  create_bd_addr_seg -range 0x10000000 -offset 0x40000000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs rab_slave/Reg] SEG_rab_slave_Reg
  create_bd_addr_seg -range 0x40000000 -offset 0x00000000 [get_bd_addr_spaces rab_acp] [get_bd_addr_segs processing_system7_0/S_AXI_ACP/ACP_DDR_LOWOCM] SEG_processing_system7_0_ACP_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x00000000 [get_bd_addr_spaces rab_master] [get_bd_addr_segs processing_system7_0/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM


  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


